
-------------------------------------------------------------------------------
-- REPMGR
--
-- This is the database setup script for the REPMGR schema.
-------------------------------------------------------------------------------

------ Change Log -------------------------------------------------------------
--  Flag  Track   Staff            Date        Description
-- ------ -----  -------------  ----------  -----------------------------------
--  none  23285  William Olsen  2006/07/06   New CSMUSER Table format.
-------------------------------------------------------------------------------

-- SQL statements to build the REPMGR related tables
-- 

CREATE SCHEMA REPMGR;

DROP TABLE REPMGR.CSMUSER_bak;
CREATE TABLE REPMGR.CSMUSER_bak
   ("NAME" VARCHAR(255) NOT NULL , 
	"TYPE" INTEGER NOT NULL , 
	"PERMISSION" VARCHAR(255) NOT NULL , 
	"RESOURCE" VARCHAR(255) NOT NULL , 
	"ACTIONS" VARCHAR(255) NOT NULL );

ALTER TABLE REPMGR.CSMUSER_bak
  ADD CONSTRAINT PK_CSMUSER_bak PRIMARY KEY (NAME, TYPE, PERMISSION, RESOURCE);
  
DROP TABLE REPMGR.CSMPROPERTIES_bak;
CREATE TABLE REPMGR.CSMPROPERTIES_bak
  (PROP_NAME VARCHAR(250) NOT NULL,
   PROP_VALUE VARCHAR(250) NOT NULL);

ALTER TABLE REPMGR.CSMPROPERTIES_bak
  ADD CONSTRAINT PK_CSMPROPER_bak PRIMARY KEY (PROP_NAME);


DROP TABLE REPMGR.DRIVER_bak;
CREATE TABLE REPMGR.DRIVER_bak
  (DRIVERID VARCHAR(250) NOT NULL,
   TYPE1 VARCHAR(250),
   ISSHADOWING SMALLINT NOT NULL,
   CONTROLCLASS VARCHAR(250),
   NUMBEROFPAIRS INTEGER NOT NULL,
   CGINFO BLOB(13000),
   SEQUENCENAME VARCHAR(250),
   SESSIONNAME VARCHAR(250) NOT NULL,
   ISDEFINED SMALLINT NOT NULL,
   TIMESTAMP1 VARCHAR(250),
   INUSE SMALLINT NOT NULL,
   HWCONSISTENCYGROUPNAME VARCHAR(250),
   ISNEW SMALLINT NOT NULL);

ALTER TABLE REPMGR.DRIVER_bak
  ADD CONSTRAINT PK_DRIVER_bak PRIMARY KEY (DRIVERID, SESSIONNAME);


DROP TABLE REPMGR.PAIR_bak;
CREATE TABLE REPMGR.PAIR_bak
  (SOURCEID VARCHAR(250) NOT NULL,
   TARGETID VARCHAR(250) NOT NULL,
   STATE1 VARCHAR(250),
   DRIVERID VARCHAR(250),
   PENDINGSTATE VARCHAR(250),
   SESSIONNAME VARCHAR(250) NOT NULL,
   SEQUENCENAME VARCHAR(250) NOT NULL, 
   ISNEW SMALLINT NOT NULL,
   TIMESTAMP1 VARCHAR(250),
   ISSHADOWING SMALLINT NOT NULL,
   ISCONSISTENT SMALLINT NOT NULL,
   LASTRESULTTYPE INTEGER NOT NULL,
   LASTRESULTMSGKEY VARCHAR(10),
   LASTRESULTINSERTS BLOB(11000),
   LASTRESULTTIME TIMESTAMP NOT NULL,
   PENDINGREASONCODE INTEGER NOT NULL,
   ISINHWCONSISTENCYGROUP SMALLINT NOT NULL,
   DIRECTION SMALLINT NOT NULL,
   COPYSETID VARCHAR(250));

ALTER TABLE REPMGR.PAIR_bak
  ADD CONSTRAINT PK_PAIR_bak PRIMARY KEY (SOURCEID, TARGETID, SESSIONNAME);

DROP TABLE REPMGR.SESSION1_bak;
CREATE TABLE REPMGR.SESSION1_bak
  (SESSIONNAME VARCHAR(250) NOT NULL,
   COPYRULES BLOB(65000),
   CMDBEINGPROCESSED VARCHAR(250),
   STATE VARCHAR(250),
   DESCRIPTION VARCHAR(250),
   PRODUCTIONROLE VARCHAR(250),
   NUMACTIVEDRIVERS INTEGER NOT NULL,
   INUSE SMALLINT NOT NULL,
   INGENERATE VARCHAR(250));

ALTER TABLE REPMGR.SESSION1_bak
  ADD CONSTRAINT PK_SESSION1_bak PRIMARY KEY (SESSIONNAME);

DROP TABLE REPMGR.COPYSET_bak;
CREATE TABLE REPMGR.COPYSET_bak
  (COPYSETID VARCHAR(250) NOT NULL,
   CONSISTENCYLEVEL VARCHAR(250),
   SESSIONNAME VARCHAR(250) NOT NULL,
   INGAME SMALLINT NOT NULL,
   ISVALID SMALLINT NOT NULL,
   ISVERIFIED SMALLINT NOT NULL);

ALTER TABLE REPMGR.COPYSET_bak
  ADD CONSTRAINT PK_COPYSET_bak PRIMARY KEY (COPYSETID, SESSIONNAME);

DROP TABLE REPMGR.POINT_bak;
CREATE TABLE REPMGR.POINT_bak
  (POINTID VARCHAR(250) NOT NULL,
   POINTNUMBER INTEGER NOT NULL,
   SESSIONID VARCHAR(250) NOT NULL,
   COPYSETID VARCHAR(250));

ALTER TABLE REPMGR.POINT_bak
  ADD CONSTRAINT PK_POINT_bak PRIMARY KEY (POINTID, SESSIONID);

DROP TABLE REPMGR.SEQUENCE_bak;
CREATE TABLE REPMGR.SEQUENCE_bak
  (SEQUENCENAME VARCHAR(250) NOT NULL,
   SESSIONNAME VARCHAR(250) NOT NULL,
   DIRECTION SMALLINT NOT NULL);

ALTER TABLE REPMGR.SEQUENCE_bak
  ADD CONSTRAINT PK_SEQUENCE_bak PRIMARY KEY (SEQUENCENAME, SESSIONNAME);

DROP TABLE REPMGR.HA_STATUS_bak;  
CREATE TABLE REPMGR.HA_STATUS_bak
 (HOSTNAME VARCHAR(250) NOT NULL,
  IPADDRESS VARCHAR(36) NOT NULL,
  ROLE SMALLINT NOT NULL DEFAULT 0,
  STATE SMALLINT NOT NULL DEFAULT 0,
  TIME_STAMP TIMESTAMP NOT NULL);

ALTER TABLE REPMGR.HA_STATUS_bak
  ADD CONSTRAINT PK_HA_STATUS_bak PRIMARY KEY (HOSTNAME, IPADDRESS);
    
DROP TABLE REPMGR.SNMP_MGRS_bak;
CREATE TABLE REPMGR.SNMP_MGRS_bak
 (MGRNAME VARCHAR (250) NOT NULL, 
  PORT INTEGER NOT NULL WITH DEFAULT 162);
  
ALTER TABLE REPMGR.SNMP_MGRS_bak
  ADD CONSTRAINT PK_SNMP_MGRS_bak PRIMARY KEY ( MGRNAME, PORT);
  
DROP TABLE REPMGR.SITELOCATIONS_bak;
CREATE TABLE REPMGR.SITELOCATIONS_bak 
   (SITELOCATIONID SMALLINT NOT NULL, 
    SESSIONNAME VARCHAR (250) NOT NULL,
    SITENAME VARCHAR(20) NOT NULL);

ALTER TABLE REPMGR.SITELOCATIONS_bak
  ADD CONSTRAINT PK_SITELOCATIONS_bak PRIMARY KEY (SESSIONNAME, SITENAME, SITELOCATIONID);
  
  